@@ -177,10 +177,11 @@ CMenuBar* CMenuBar::Load(CMainFrame* pMainFrame)
 #endif
 
 	if (COptions::Get()->GetOptionVal(OPTION_DEBUG_MENU)) {
-		wxMenu* pMenu = wxXmlResource::Get()->LoadMenu(_T("ID_MENU_DEBUG"));
-		if (pMenu) {
-			menubar->Append(pMenu, _("&Debug"));
-		}
+		wxMenu * debug = new wxMenu;
+		debug->Append(XRCID("ID_CLEARCACHE_LAYOUT"), _("Clear &layout cache"));
+		debug->Append(XRCID("ID_CIPHERS"), _("&TLS Ciphers"), _("Shows available TLS ciphers"));
+		debug->Append(XRCID("ID_CLEAR_UPDATER"), _("Clear auto&update data"));
+		menubar->Append(debug, _("&Debug"));
 	}
 
 	menubar->UpdateBookmarkMenu();
@@ -220,8 +221,9 @@ CMenuBar* CMenuBar::Load(CMainFrame* pMainFrame)
 
 	menubar->UpdateSpeedLimitMenuItem();
 
-	if (COptions::Get()->GetOptionVal(OPTION_MESSAGELOG_POSITION) == 2)
+	if (COptions::Get()->GetOptionVal(OPTION_MESSAGELOG_POSITION) == 2) {
 		menubar->HideItem(XRCID("ID_VIEW_MESSAGELOG"));
+	}
 
 	menubar->UpdateMenubarState();
 
@@ -373,8 +375,9 @@ void CMenuBar::OnMenuEvent(wxCommandEvent& event)
 		CContextControl* pContextControl = m_pMainFrame ? m_pMainFrame->GetContextControl() : 0;
 		CContextControl::_context_controls* controls = pContextControl ? pContextControl->GetCurrentControls() : 0;
 		CState* pState = controls ? controls->pState : 0;
-		if (!pState)
+		if (!pState) {
 			return;
+		}
 
 		Site site = pState->GetSite();
 		if (!site.server_) {
@@ -436,7 +439,7 @@ void CMenuBar::OnMenuEvent(wxCommandEvent& event)
 					wxMessageBoxEx(_("Selected global bookmark and current server use a different server type.\nUse site-specific bookmarks for this server."), _("Bookmark"), wxICON_EXCLAMATION, this);
 					return;
 				}
-				pState->ChangeRemoteDir(remote_dir, _T(""), 0, false, comparison);
+				pState->ChangeRemoteDir(remote_dir, std::wstring(), 0, false, comparison);
 			}
 		}
 		if (!local_dir.empty()) {
@@ -538,14 +541,17 @@ void CMenuBar::OnOptionsChanged(changed_options_t const& options)
 		Check(XRCID("ID_COMPARE_HIDEIDENTICAL"), COptions::Get()->GetOptionVal(OPTION_COMPARE_HIDEIDENTICAL) != 0);
 	}
 	if (options.test(OPTION_COMPARISONMODE)) {
-		if (COptions::Get()->GetOptionVal(OPTION_COMPARISONMODE) != 1)
+		if (COptions::Get()->GetOptionVal(OPTION_COMPARISONMODE) != 1) {
 			Check(XRCID("ID_COMPARE_SIZE"), true);
-		else
+		}
+		else {
 			Check(XRCID("ID_COMPARE_DATE"), true);
+		}
 	}
 	if (options.test(OPTION_MESSAGELOG_POSITION)) {
-		if (COptions::Get()->GetOptionVal(OPTION_MESSAGELOG_POSITION) == 2)
+		if (COptions::Get()->GetOptionVal(OPTION_MESSAGELOG_POSITION) == 2) {
 			HideItem(XRCID("ID_VIEW_MESSAGELOG"));
+		}
 		else {
 			ShowItem(XRCID("ID_VIEW_MESSAGELOG"));
 			Check(XRCID("ID_VIEW_MESSAGELOG"), COptions::Get()->GetOptionVal(OPTION_SHOW_MESSAGELOG) != 0);
@@ -563,8 +569,9 @@ void CMenuBar::UpdateSpeedLimitMenuItem()
 	int downloadLimit = COptions::Get()->GetOptionVal(OPTION_SPEEDLIMIT_INBOUND);
 	int uploadLimit = COptions::Get()->GetOptionVal(OPTION_SPEEDLIMIT_OUTBOUND);
 
-	if (!downloadLimit && !uploadLimit)
+	if (!downloadLimit && !uploadLimit) {
 		enable = false;
+	}
 
 	Check(XRCID("ID_MENU_TRANSFER_SPEEDLIMITS_ENABLE"), enable);
 }
@@ -589,8 +596,9 @@ void CMenuBar::UpdateMenubarState()
 	Check(XRCID("ID_TOOLBAR_SYNCHRONIZED_BROWSING"), pState->GetSyncBrowse());
 
 	bool canReconnect;
-	if (server || !idle)
+	if (server || !idle) {
 		canReconnect = false;
+	}
 	else {
 		canReconnect = static_cast<bool>(pState->GetLastSite().server_);
 	}
@@ -614,8 +622,9 @@ bool CMenuBar::ShowItem(int id)
 
 			menu_iter->first->Insert(iter->first - offset, iter->second);
 			menu_iter->second.erase(iter);
-			if (menu_iter->second.empty())
+			if (menu_iter->second.empty()) {
 				m_hidden_items.erase(menu_iter);
+			}
 
 			return true;
 		}
@@ -627,26 +636,29 @@ bool CMenuBar::HideItem(int id)
 {
 	wxMenu* pMenu = 0;
 	wxMenuItem* pItem = FindItem(id, &pMenu);
-	if (!pItem || !pMenu)
+	if (!pItem || !pMenu) {
 		return false;
+	}
 
 	size_t pos;
 	pItem = pMenu->FindChildItem(id, &pos);
-	if (!pItem)
+	if (!pItem) {
 		return false;
+	}
 
 	pMenu->Remove(pItem);
 
 	auto menu_iter = m_hidden_items.insert(std::make_pair(pMenu, std::map<int, wxMenuItem*>())).first;
 
 	for (auto iter = menu_iter->second.begin(); iter != menu_iter->second.end(); ++iter) {
-		if (iter->first > (int)pos)
+		if (iter->first > static_cast<int>(pos)) {
 			break;
+		}
 
 		pos++;
 	}
 
-	menu_iter->second[(int)pos] = pItem;
+	menu_iter->second[static_cast<int>(pos)] = pItem;
 
 	return true;
 }
