@@ -3,14 +3,31 @@
 #include "settingsdialog.h"
 #include "optionspage.h"
 
+wxSizerFlags const COptionsPage::grow(wxSizerFlags().Expand());
+wxSizerFlags const COptionsPage::valign(wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL));
+wxSizerFlags const COptionsPage::valigng(wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL).Expand());
+
 bool COptionsPage::CreatePage(COptions* pOptions, CSettingsDialog* pOwner, wxWindow* parent, wxSize& maxSize)
 {
 	m_pOwner = pOwner;
 	m_pOptions = pOptions;
 
-	if (!wxXmlResource::Get()->LoadPanel(this, parent, GetResourceName()))
+	if (!CreateControls(parent)) {
 		return false;
+	}
 
+	UpdateMaxPageSize(maxSize);
+
+	return true;
+}
+
+bool COptionsPage::CreateControls(wxWindow* parent)
+{
+	return wxXmlResource::Get()->LoadPanel(this, parent, GetResourceName());
+}
+
+void COptionsPage::UpdateMaxPageSize(wxSize& maxSize)
+{
 	wxSize size = GetSize();
 
 #ifdef __WXGTK__
@@ -20,14 +37,12 @@ bool COptionsPage::CreatePage(COptions* pOptions, CSettingsDialog* pOwner, wxWin
 	size.x += 1;
 #endif
 
-	if (size.GetWidth() > maxSize.GetWidth())
+	if (size.GetWidth() > maxSize.GetWidth()) {
 		maxSize.SetWidth(size.GetWidth());
-	if (size.GetHeight() > maxSize.GetHeight())
+	}
+	if (size.GetHeight() > maxSize.GetHeight()) {
 		maxSize.SetHeight(size.GetHeight());
-
-	m_was_selected = false;
-
-	return true;
+	}
 }
 
 void COptionsPage::SetCheck(int id, bool checked, bool& failure)
@@ -143,7 +158,7 @@ void COptionsPage::ReloadSettings()
 void COptionsPage::SetOptionFromText(int ctrlId, int optionId)
 {
 	const wxString& value = GetText(ctrlId);
-	m_pOptions->SetOption(optionId, value);
+	m_pOptions->SetOption(optionId, value.ToStdWstring());
 }
 
 void COptionsPage::SetIntOptionFromText(int ctrlId, int optionId)
@@ -181,8 +196,9 @@ int COptionsPage::GetChoice(int id) const
 {
 	auto pChoice = dynamic_cast<wxChoice*>(FindWindow(id));
 	wxASSERT(pChoice);
-	if (!pChoice)
+	if (!pChoice) {
 		return 0;
+	}
 
 	return pChoice->GetSelection();
 }
@@ -190,18 +206,21 @@ int COptionsPage::GetChoice(int id) const
 bool COptionsPage::DisplayError(const wxString& controlToFocus, const wxString& error)
 {
 	int id = wxXmlResource::GetXRCID(controlToFocus);
-	if (id == -1)
+	if (id == -1) {
 		DisplayError(0, error);
-	else
+	}
+	else {
 		DisplayError(FindWindow(id), error);
+	}
 
 	return false;
 }
 
 bool COptionsPage::DisplayError(wxWindow* pWnd, const wxString& error)
 {
-	if (pWnd)
+	if (pWnd) {
 		pWnd->SetFocus();
+	}
 
 	wxMessageBoxEx(error, _("Failed to validate settings"), wxICON_EXCLAMATION, this);
 
@@ -210,10 +229,10 @@ bool COptionsPage::DisplayError(wxWindow* pWnd, const wxString& error)
 
 bool COptionsPage::Display()
 {
-	if (!m_was_selected)
-	{
-		if (!OnDisplayedFirstTime())
+	if (!m_was_selected) {
+		if (!OnDisplayedFirstTime()) {
 			return false;
+		}
 		m_was_selected = true;
 	}
 	Show();
