@@ -4,9 +4,9 @@
 class COptionsPageConnectionFTP final : public COptionsPage
 {
 public:
-	virtual wxString GetResourceName() { return _T("ID_SETTINGS_CONNECTION_FTP"); }
-	virtual bool LoadPage();
-	virtual bool SavePage();
+	virtual wxString GetResourceName() const override { return _T("ID_SETTINGS_CONNECTION_FTP"); }
+	virtual bool LoadPage() override;
+	virtual bool SavePage() override;
 };
 
 #endif
