@@ -12,7 +12,7 @@
 #include <algorithm>
 
 static const int statbarWidths[3] = {
-	-3, 0, 25
+	-1, 0, 0
 };
 #define FIELD_QUEUESIZE 1
 
@@ -86,6 +86,10 @@ void wxStatusBarEx::SetStatusWidths(int n, const int *widths)
 	for (int i = 0; i < n; ++i) {
 		m_columnWidths[i] = widths[i];
 	}
+	m_columnWidths[n - 1] += CThemeProvider::GetIconSize(iconSizeSmall).GetWidth();
+#ifdef __WXMSW__
+	m_columnWidths[n - 1] -= 18; // Internal magic constant of wx, it doesn't UI scale :(
+#endif
 
 	FixupFieldWidth(n - 1);
 
@@ -142,10 +146,10 @@ void wxStatusBarEx::OnSize(wxSizeEvent&)
 			m_parentWasMaximized = isMaximized;
 
 			if (isMaximized) {
-				m_columnWidths[count - 1] -= 16;
+				m_columnWidths[count - 1] -= CThemeProvider::GetIconSize(iconSizeSmall).GetWidth();
 			}
 			else {
-				m_columnWidths[count - 1] += 16;
+				m_columnWidths[count - 1] += CThemeProvider::GetIconSize(iconSizeSmall).GetWidth();
 			}
 
 			wxStatusBar::SetStatusWidths(count, m_columnWidths);
@@ -156,7 +160,7 @@ void wxStatusBarEx::OnSize(wxSizeEvent&)
 }
 
 #ifdef __WXGTK__
-void wxStatusBarEx::SetStatusText(const wxString& text, int number /*=0*/)
+void wxStatusBarEx::SetStatusText(const wxString& text, int number)
 {
 	wxString oldText = GetStatusText(number);
 	if (oldText != text) {
@@ -219,6 +223,10 @@ bool CWidgetsStatusBar::AddField(int field, int idx, wxWindow* pChild)
 
 	m_children[idx] = data;
 
+	if (statbarWidths[field] >= 0) {
+		SetFieldWidth(field, GetStatusWidth(field) + pChild->GetSize().GetWidth() + 3);
+	}
+
 	PositionChildren(field);
 
 	return true;
@@ -238,8 +246,7 @@ void CWidgetsStatusBar::PositionChildren(int field)
 {
 	wxRect rect;
 	GetFieldRect(field, rect);
-
-	int offset = 2;
+	int offset = 3;
 
 #ifndef __WXMSW__
 	if (field + 1 == GetFieldsCount()) {
@@ -486,8 +493,9 @@ void CStatusBar::UpdateSizeFormat()
 	// 0 equals bytes, however just use IEC binary prefixes instead,
 	// exact byte counts for queue make no sense.
 	m_sizeFormat = CSizeFormat::_format(COptions::Get()->GetOptionVal(OPTION_SIZE_FORMAT));
-	if (!m_sizeFormat)
+	if (!m_sizeFormat) {
 		m_sizeFormat = CSizeFormat::iec;
+	}
 
 	m_sizeFormatThousandsSep = COptions::Get()->GetOptionVal(OPTION_SIZE_USETHOUSANDSEP) != 0;
 	m_sizeFormatDecimalPlaces = COptions::Get()->GetOptionVal(OPTION_SIZE_DECIMALPLACES);
@@ -512,8 +520,9 @@ void CStatusBar::OnHandleLeftClick(wxWindow* pWnd)
 			CSftpEncryptioInfoDialog dlg;
 			dlg.ShowDialog(pSftpEncryptionNotification);
 		}
-		else
+		else {
 			wxMessageBoxEx(_("Certificate and session data are not available yet."), _("Security information"));
+		}
 	}
 	else if (pWnd == m_pSpeedLimitsIndicator) {
 		CSpeedLimitsDialog dlg;
@@ -530,44 +539,44 @@ void CStatusBar::OnHandleRightClick(wxWindow* pWnd)
 		ShowDataTypeMenu();
 	}
 	else if (pWnd == m_pSpeedLimitsIndicator) {
-		wxMenu* pMenu = wxXmlResource::Get()->LoadMenu(_T("ID_MENU_SPEEDLIMITCONTEXT"));
-		if (!pMenu)
-			return;
 
 		int downloadlimit = COptions::Get()->GetOptionVal(OPTION_SPEEDLIMIT_INBOUND);
 		int uploadlimit = COptions::Get()->GetOptionVal(OPTION_SPEEDLIMIT_OUTBOUND);
 		bool enable = COptions::Get()->GetOptionVal(OPTION_SPEEDLIMIT_ENABLE) != 0;
-		if (!downloadlimit && !uploadlimit)
+		if (!downloadlimit && !uploadlimit) {
 			enable = false;
-		pMenu->Check(XRCID("ID_SPEEDLIMITCONTEXT_ENABLE"), enable);
+		}
 
-		PopupMenu(pMenu);
-		delete pMenu;
+		wxMenu menu;
+		menu.Append(XRCID("ID_SPEEDLIMITCONTEXT_ENABLE"), _("&Enable"), wxString(), wxITEM_CHECK)->Check(enable);
+		menu.Append(XRCID("ID_SPEEDLIMITCONTEXT_CONFIGURE"), _("&Configure speed limits..."));
+
+		PopupMenu(&menu);
 	}
 }
 
 void CStatusBar::ShowDataTypeMenu()
 {
-	wxMenu* pMenu = wxXmlResource::Get()->LoadMenu(_T("ID_MENU_TRANSFER_TYPE_CONTEXT"));
-	if (!pMenu)
-		return;
+	wxMenu menu;
+	menu.Append(XRCID("ID_MENU_TRANSFER_TYPE_AUTO"), _("&Auto"), wxString(), wxITEM_RADIO);
+    menu.Append(XRCID("ID_MENU_TRANSFER_TYPE_ASCII"), _("A&SCII"), wxString(), wxITEM_RADIO); 
+	menu.Append(XRCID("ID_MENU_TRANSFER_TYPE_BINARY"), _("&Binary"), wxString(), wxITEM_RADIO);
 
 	const int type = COptions::Get()->GetOptionVal(OPTION_ASCIIBINARY);
 	switch (type)
 	{
 	case 1:
-		pMenu->Check(XRCID("ID_MENU_TRANSFER_TYPE_ASCII"), true);
+		menu.Check(XRCID("ID_MENU_TRANSFER_TYPE_ASCII"), true);
 		break;
 	case 2:
-		pMenu->Check(XRCID("ID_MENU_TRANSFER_TYPE_BINARY"), true);
+		menu.Check(XRCID("ID_MENU_TRANSFER_TYPE_BINARY"), true);
 		break;
 	default:
-		pMenu->Check(XRCID("ID_MENU_TRANSFER_TYPE_AUTO"), true);
+		menu.Check(XRCID("ID_MENU_TRANSFER_TYPE_AUTO"), true);
 		break;
 	}
 
-	PopupMenu(pMenu);
-	delete pMenu;
+	PopupMenu(&menu);
 }
 
 void CStatusBar::UpdateSpeedLimitsIcon()
